==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/GetPeriodicTimerEventTriggerPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.GetPeriodicTimerEventTriggerPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deviceName The device name.
 * @property name The trigger name.
 * @property resourceGroupName The resource group name.
 */
public data class GetPeriodicTimerEventTriggerPlainArgs(
    public val deviceName: String,
    public val name: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.GetPeriodicTimerEventTriggerPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.databoxedge.inputs.GetPeriodicTimerEventTriggerPlainArgs =
        com.pulumi.azurenative.databoxedge.inputs.GetPeriodicTimerEventTriggerPlainArgs.builder()
            .deviceName(deviceName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPeriodicTimerEventTriggerPlainArgs].
 */
@PulumiTagMarker
public class GetPeriodicTimerEventTriggerPlainArgsBuilder internal constructor() {
    private var deviceName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The device name.
     */
    @JvmName("fplemwcytfbdkhft")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The trigger name.
     */
    @JvmName("vvcwhqnjmdifduxe")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("vlqnlhndnckmsunp")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetPeriodicTimerEventTriggerPlainArgs =
        GetPeriodicTimerEventTriggerPlainArgs(
            deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/GetPeriodicTimerEventTriggerPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.GetPeriodicTimerEventTriggerPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deviceName The device name.
 * @property name The trigger name.
 * @property resourceGroupName The resource group name.
 */
public data class GetPeriodicTimerEventTriggerPlainArgs(
    public val deviceName: String,
    public val name: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.GetPeriodicTimerEventTriggerPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.databoxedge.inputs.GetPeriodicTimerEventTriggerPlainArgs =
        com.pulumi.azurenative.databoxedge.inputs.GetPeriodicTimerEventTriggerPlainArgs.builder()
            .deviceName(deviceName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPeriodicTimerEventTriggerPlainArgs].
 */
@PulumiTagMarker
public class GetPeriodicTimerEventTriggerPlainArgsBuilder internal constructor() {
    private var deviceName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The device name.
     */
    @JvmName("niwelqnmfeapksvb")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The trigger name.
     */
    @JvmName("xuynpbrjsqaubmul")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("uxnevcvplncfdxcd")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetPeriodicTimerEventTriggerPlainArgs =
        GetPeriodicTimerEventTriggerPlainArgs(
            deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
